@@ -7,36 +7,30 @@ psycopg -- PostgreSQL database adapter for Python
 import logging
 
 from . import pq  # noqa: F401 import early to stabilize side effects
-from . import types
-from . import postgres
+from . import dbapi20, postgres, types
 from ._tpc import Xid
-from .copy import Copy, AsyncCopy
+from .copy import AsyncCopy, Copy
 from ._enums import IsolationLevel
 from .cursor import Cursor
-from .errors import Warning, Error, InterfaceError, DatabaseError
-from .errors import DataError, OperationalError, IntegrityError
-from .errors import InternalError, ProgrammingError, NotSupportedError
+from .errors import DatabaseError, DataError, Error, IntegrityError, InterfaceError
+from .errors import InternalError, NotSupportedError, OperationalError
+from .errors import ProgrammingError, Warning
 from ._column import Column
-from ._pipeline import Pipeline, AsyncPipeline
+from .dbapi20 import BINARY, DATETIME, NUMBER, ROWID, STRING, Binary, Date
+from .dbapi20 import DateFromTicks, Time, TimeFromTicks, Timestamp, TimestampFromTicks
+from .version import __version__ as __version__  # noqa: F401
+from ._pipeline import AsyncPipeline, Pipeline
 from .connection import Connection
-from .transaction import Rollback, Transaction, AsyncTransaction
+from .raw_cursor import AsyncRawCursor, AsyncRawServerCursor, RawCursor, RawServerCursor
+from .transaction import AsyncTransaction, Rollback, Transaction
 from .cursor_async import AsyncCursor
 from ._capabilities import Capabilities, capabilities
-from .server_cursor import AsyncServerCursor, ServerCursor
 from .client_cursor import AsyncClientCursor, ClientCursor
-from .raw_cursor import AsyncRawCursor, RawCursor
-from .raw_cursor import AsyncRawServerCursor, RawServerCursor
+from .server_cursor import AsyncServerCursor, ServerCursor
 from ._connection_base import BaseConnection, Notify
 from ._connection_info import ConnectionInfo
 from .connection_async import AsyncConnection
 
-from . import dbapi20
-from .dbapi20 import BINARY, DATETIME, NUMBER, ROWID, STRING
-from .dbapi20 import Binary, Date, DateFromTicks, Time, TimeFromTicks
-from .dbapi20 import Timestamp, TimestampFromTicks
-
-from .version import __version__ as __version__  # noqa: F401
-
 # Set the logger to a quiet default, can be enabled if needed
 logger = logging.getLogger("psycopg")
 if logger.level == logging.NOTSET:
