@@ -20,16 +20,16 @@ DBAPI-defined Exceptions are defined in the following hierarchy::
 
 from __future__ import annotations
 
-from dataclasses import dataclass, field, fields
-from typing import Any, Callable, NoReturn, Sequence, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, NoReturn, Sequence
 from asyncio import CancelledError
+from dataclasses import dataclass, field, fields
 
 from .pq.abc import PGconn, PGresult
-from .pq._enums import ConnStatus, DiagnosticField, PipelineStatus, TransactionStatus
 from ._compat import TypeAlias, TypeGuard
+from .pq._enums import ConnStatus, DiagnosticField, PipelineStatus, TransactionStatus
 
 if TYPE_CHECKING:
-    from .pq.misc import PGnotify, ConninfoOption
+    from .pq.misc import ConninfoOption, PGnotify
 
 ErrorInfo: TypeAlias = "PGresult | dict[int, bytes | None] | None"
 
