@@ -25,12 +25,12 @@ from __future__ import annotations
 import logging
 from time import monotonic
 
-from . import pq
 from . import errors as e
+from . import pq
 from .abc import Buffer, PipelineCommand, PQGen, PQGenConn
 from .pq.abc import PGcancelConn, PGconn, PGresult
-from .waiting import Wait, Ready
 from ._compat import Deque
+from .waiting import Ready, Wait
 from ._cmodule import _psycopg
 from ._encodings import conninfo_encoding
 
