@@ -9,8 +9,8 @@ from __future__ import annotations
 import sys
 import ctypes
 import ctypes.util
-from ctypes import Structure, CFUNCTYPE, POINTER
-from ctypes import c_char, c_char_p, c_int, c_size_t, c_ubyte, c_uint, c_void_p
+from ctypes import CFUNCTYPE, POINTER, Structure, c_char, c_char_p, c_int, c_size_t
+from ctypes import c_ubyte, c_uint, c_void_p
 from typing import Any, NoReturn
 
 from .misc import find_libpq_full_path, version_pretty
