@@ -7,13 +7,11 @@ Transaction context managers returned by Connection.transaction()
 from __future__ import annotations
 
 import logging
-
 from types import TracebackType
-from typing import Any, Generic, Iterator, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Generic, Iterator
 
-from . import pq
-from . import sql
 from . import errors as e
+from . import pq, sql
 from .abc import ConnectionType, PQGen
 from ._compat import Self
 from .pq.misc import connection_summary
