@@ -4,31 +4,33 @@ Adapters for network types.
 
 # Copyright (C) 2020 The Psycopg Team
 
-from typing import Callable, Optional, Type, Union, TYPE_CHECKING
-from typing_extensions import TypeAlias
+from __future__ import annotations
 
-from .. import postgres
+from typing import TYPE_CHECKING, Callable
+
+from .. import _oids
 from ..pq import Format
 from ..abc import AdaptContext
 from ..adapt import Buffer, Dumper, Loader
+from .._compat import TypeAlias
 
 if TYPE_CHECKING:
     import ipaddress
 
-Address: TypeAlias = Union["ipaddress.IPv4Address", "ipaddress.IPv6Address"]
-Interface: TypeAlias = Union["ipaddress.IPv4Interface", "ipaddress.IPv6Interface"]
-Network: TypeAlias = Union["ipaddress.IPv4Network", "ipaddress.IPv6Network"]
+Address: TypeAlias = "ipaddress.IPv4Address | ipaddress.IPv6Address"
+Interface: TypeAlias = "ipaddress.IPv4Interface | ipaddress.IPv6Interface"
+Network: TypeAlias = "ipaddress.IPv4Network | ipaddress.IPv6Network"
 
 # These objects will be imported lazily
 ip_address: Callable[[str], Address] = None  # type: ignore[assignment]
 ip_interface: Callable[[str], Interface] = None  # type: ignore[assignment]
 ip_network: Callable[[str], Network] = None  # type: ignore[assignment]
-IPv4Address: "Type[ipaddress.IPv4Address]" = None  # type: ignore[assignment]
-IPv6Address: "Type[ipaddress.IPv6Address]" = None  # type: ignore[assignment]
-IPv4Interface: "Type[ipaddress.IPv4Interface]" = None  # type: ignore[assignment]
-IPv6Interface: "Type[ipaddress.IPv6Interface]" = None  # type: ignore[assignment]
-IPv4Network: "Type[ipaddress.IPv4Network]" = None  # type: ignore[assignment]
-IPv6Network: "Type[ipaddress.IPv6Network]" = None  # type: ignore[assignment]
+IPv4Address: type[ipaddress.IPv4Address] = None  # type: ignore[assignment]
+IPv6Address: type[ipaddress.IPv6Address] = None  # type: ignore[assignment]
+IPv4Interface: type[ipaddress.IPv4Interface] = None  # type: ignore[assignment]
+IPv6Interface: type[ipaddress.IPv6Interface] = None  # type: ignore[assignment]
+IPv4Network: type[ipaddress.IPv4Network] = None  # type: ignore[assignment]
+IPv6Network: type[ipaddress.IPv6Network] = None  # type: ignore[assignment]
 
 PGSQL_AF_INET = 2
 PGSQL_AF_INET6 = 3
@@ -43,33 +45,32 @@ class _LazyIpaddress:
         global IPv4Network, IPv6Network
 
         if ip_address is None:
-            from ipaddress import ip_address, ip_interface, ip_network
-            from ipaddress import IPv4Address, IPv6Address
-            from ipaddress import IPv4Interface, IPv6Interface
-            from ipaddress import IPv4Network, IPv6Network
+            from ipaddress import IPv4Address, IPv4Interface, IPv4Network, IPv6Address
+            from ipaddress import IPv6Interface, IPv6Network, ip_address, ip_interface
+            from ipaddress import ip_network
 
 
 class InterfaceDumper(Dumper):
-    oid = postgres.types["inet"].oid
+    oid = _oids.INET_OID
 
-    def dump(self, obj: Interface) -> bytes:
+    def dump(self, obj: Interface) -> Buffer | None:
         return str(obj).encode()
 
 
 class NetworkDumper(Dumper):
-    oid = postgres.types["cidr"].oid
+    oid = _oids.CIDR_OID
 
-    def dump(self, obj: Network) -> bytes:
+    def dump(self, obj: Network) -> Buffer | None:
         return str(obj).encode()
 
 
 class _AIBinaryDumper(Dumper):
     format = Format.BINARY
-    oid = postgres.types["inet"].oid
+    oid = _oids.INET_OID
 
 
 class AddressBinaryDumper(_AIBinaryDumper):
-    def dump(self, obj: Address) -> bytes:
+    def dump(self, obj: Address) -> Buffer | None:
         packed = obj.packed
         family = PGSQL_AF_INET if obj.version == 4 else PGSQL_AF_INET6
         head = bytes((family, obj.max_prefixlen, 0, len(packed)))
@@ -77,7 +78,7 @@ class AddressBinaryDumper(_AIBinaryDumper):
 
 
 class InterfaceBinaryDumper(_AIBinaryDumper):
-    def dump(self, obj: Interface) -> bytes:
+    def dump(self, obj: Interface) -> Buffer | None:
         packed = obj.packed
         family = PGSQL_AF_INET if obj.version == 4 else PGSQL_AF_INET6
         head = bytes((family, obj.network.prefixlen, 0, len(packed)))
@@ -90,11 +91,11 @@ class InetBinaryDumper(_AIBinaryDumper, _LazyIpaddress):
     Used when looking up by oid.
     """
 
-    def __init__(self, cls: type, context: Optional[AdaptContext] = None):
+    def __init__(self, cls: type, context: AdaptContext | None = None):
         super().__init__(cls, context)
         self._ensure_module()
 
-    def dump(self, obj: Union[Address, Interface]) -> bytes:
+    def dump(self, obj: Address | Interface) -> Buffer | None:
         packed = obj.packed
         family = PGSQL_AF_INET if obj.version == 4 else PGSQL_AF_INET6
         if isinstance(obj, (IPv4Interface, IPv6Interface)):
@@ -108,9 +109,9 @@ class InetBinaryDumper(_AIBinaryDumper, _LazyIpaddress):
 
 class NetworkBinaryDumper(Dumper):
     format = Format.BINARY
-    oid = postgres.types["cidr"].oid
+    oid = _oids.CIDR_OID
 
-    def dump(self, obj: Network) -> bytes:
+    def dump(self, obj: Network) -> Buffer | None:
         packed = obj.network_address.packed
         family = PGSQL_AF_INET if obj.version == 4 else PGSQL_AF_INET6
         head = bytes((family, obj.prefixlen, 1, len(packed)))
@@ -118,13 +119,13 @@ class NetworkBinaryDumper(Dumper):
 
 
 class _LazyIpaddressLoader(Loader, _LazyIpaddress):
-    def __init__(self, oid: int, context: Optional[AdaptContext] = None):
+    def __init__(self, oid: int, context: AdaptContext | None = None):
         super().__init__(oid, context)
         self._ensure_module()
 
 
 class InetLoader(_LazyIpaddressLoader):
-    def load(self, data: Buffer) -> Union[Address, Interface]:
+    def load(self, data: Buffer) -> Address | Interface:
         if isinstance(data, memoryview):
             data = bytes(data)
 
@@ -137,7 +138,7 @@ class InetLoader(_LazyIpaddressLoader):
 class InetBinaryLoader(_LazyIpaddressLoader):
     format = Format.BINARY
 
-    def load(self, data: Buffer) -> Union[Address, Interface]:
+    def load(self, data: Buffer) -> Address | Interface:
         if isinstance(data, memoryview):
             data = bytes(data)
 
