@@ -9,10 +9,10 @@ import pytest
 
 import psycopg
 from psycopg.pq import TransactionStatus
-from psycopg.rows import class_row, Row, TupleRow
+from psycopg.rows import Row, TupleRow, class_row
 
-from ..utils import assert_type, Counter, set_autocommit
-from ..acompat import AEvent, spawn, gather, asleep, skip_sync
+from ..utils import Counter, assert_type, set_autocommit
+from ..acompat import AEvent, asleep, gather, skip_sync, spawn
 from .test_pool_common_async import delay_connection
 
 try:
