@@ -2,22 +2,24 @@ from __future__ import annotations
 
 import sys
 import time
-import pytest
 import logging
 import weakref
 from typing import Any
 
+import pytest
+
 import psycopg
-from psycopg import pq, errors as e
+from psycopg import errors as e
+from psycopg import pq
 from psycopg.rows import tuple_row
 from psycopg.conninfo import conninfo_to_dict, timeout_from_conninfo
 
-from .acompat import is_async, skip_sync, skip_async, asleep
-from ._test_cursor import my_row_factory
-from ._test_connection import tx_params, tx_params_isolation, tx_values_map
-from ._test_connection import conninfo_params_timeout
-from ._test_connection import testctx  # noqa: F401  # fixture
+from .acompat import asleep, is_async, skip_async, skip_sync
 from .test_adapt import make_bin_dumper, make_dumper
+from ._test_cursor import my_row_factory
+from ._test_connection import testctx  # noqa: F401  # fixture
+from ._test_connection import conninfo_params_timeout, tx_params, tx_params_isolation
+from ._test_connection import tx_values_map
 
 
 async def test_connect(aconn_cls, dsn):
@@ -907,3 +909,21 @@ async def test_right_exception_on_session_timeout(aconn):
     # This check is here to monitor if the behaviour on Window chamge.
     # Rreceiving the same exception of other platform will be acceptable.
     assert type(ex.value) is want_ex
+
+
+@pytest.mark.libpq(">= 14")
+@pytest.mark.parametrize("mode", ["any", "read-write", "primary", "prefer-standby"])
+async def test_connect_tsa(aconn_cls, dsn, mode):
+    # NOTE: assume that the test database is a "primary"
+    params = conninfo_to_dict(dsn, target_session_attrs=mode)
+    async with await aconn_cls.connect(**params) as aconn:
+        assert aconn.pgconn.status == pq.ConnStatus.OK
+
+
+@pytest.mark.libpq(">= 14")
+@pytest.mark.parametrize("mode", ["read-only", "standby", "nosuchmode"])
+async def test_connect_tsa_bad(aconn_cls, dsn, mode):
+    # NOTE: assume that the test database is a "primary"
+    params = conninfo_to_dict(dsn, target_session_attrs=mode)
+    with pytest.raises(psycopg.OperationalError, match=mode):
+        await aconn_cls.connect(**params)
