@@ -18,17 +18,17 @@ def test_connect(monkeypatch, dsn_env, args, kwargs, want, setpgenv):
     # Details of the params manipulation are in test_conninfo.
     import psycopg.connection
 
-    orig_connect = psycopg.connection.connect  # type: ignore
+    orig_connect = psycopg.generators.connect
 
     got_conninfo: str
 
-    def mock_connect(conninfo):
+    def mock_connect(conninfo, *, timeout):
         nonlocal got_conninfo
         got_conninfo = conninfo
-        return orig_connect(dsn_env)
+        return orig_connect(dsn_env, timeout=timeout)
 
     setpgenv({})
-    monkeypatch.setattr(psycopg.connection, "connect", mock_connect)
+    monkeypatch.setattr(psycopg.generators, "connect", mock_connect)
 
     conn = psycopg.connect(*args, **kwargs)
     assert conninfo_to_dict(got_conninfo) == conninfo_to_dict(want)
