@@ -1,9 +1,8 @@
 from psycopg import sql
-from psycopg.adapt import Transformer, PyFormat
+from psycopg.adapt import PyFormat, Transformer
 
 
 def test_quote_none(conn):
-
     tx = Transformer()
     assert tx.get_dumper(None, PyFormat.TEXT).quote(None) == b"NULL"
 
